@@ -1,4 +1,6 @@
-import sys
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -6,10 +8,13 @@ from virtualenv import cli_run
 from virtualenv.info import IS_PYPY
 from virtualenv.util.subprocess import run_cmd
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
 
 @pytest.mark.skipif(IS_PYPY, reason="setuptools distutils patching does not work")
-def test_app_data_pinning(tmp_path):
-    version = "19.1.1" if sys.version_info[0:2] == (3, 4) else "19.3.1"
+def test_app_data_pinning(tmp_path: Path) -> None:
+    version = "23.1"
     result = cli_run([str(tmp_path), "--pip", version, "--activators", "", "--seeder", "app-data"])
     code, out, _ = run_cmd([str(result.creator.script("pip")), "list", "--disable-pip-version-check"])
     assert not code
